# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global short_name    framework
%global short_Name    Avalon

Name:        avalon-%{short_name}
Version:     4.3
Release:     5
Summary:     Java components interfaces
License:     ASL 2.0
URL:         http://avalon.apache.org/%{short_name}/
Group:       Development/Java
Source0:     http://archive.apache.org/dist/excalibur/avalon-framework/source/%{name}-api-%{version}-src.tar.gz
Source1:     http://archive.apache.org/dist/excalibur/avalon-framework/source/%{name}-impl-%{version}-src.tar.gz

# pom files are not provided in tarballs so get them from external site
Source2:     http://repo1.maven.org/maven2/avalon-framework/%{name}-api/%{version}/%{name}-api-%{version}.pom
Source3:     http://repo1.maven.org/maven2/avalon-framework/%{name}-impl/%{version}/%{name}-impl-%{version}.pom

# remove jmock from dependencies because we don't have it
Patch0:     %{name}-impl-pom.patch

Requires:    apache-commons-logging
Requires:    avalon-logkit
Requires:    log4j
Requires:    xalan-j2
Requires:    xml-commons-apis

Requires(post):    jpackage-utils
Requires(postun):  jpackage-utils

BuildRequires:    ant
BuildRequires:	  ant-junit
BuildRequires:	  apache-commons-logging
BuildRequires:    avalon-logkit
BuildRequires:    jpackage-utils
# For converting jar into OSGi bundle
BuildRequires:    aqute-bndlib
BuildRequires:    junit
BuildRequires:	  log4j
BuildRequires:    xml-commons-apis


BuildArch:    	  noarch

Obsoletes:    %{name}-manual <= 0:4.1.4

%description
The Avalon framework consists of interfaces that define relationships
between commonly used application components, best-of-practice pattern
enforcements, and several lightweight convenience implementations of the
generic components.
What that means is that we define the central interface Component. We
also define the relationship (contract) a component has with peers,
ancestors and children.

%package javadoc
Summary:      API documentation %{name}
Group:        Development/Java
Requires:     jpackage-utils

%description javadoc
%{summary}.

%prep
%setup -q -n %{name}-api-%{version}
tar xvf %{SOURCE1}

cp %{SOURCE2} .

pushd %{name}-impl-%{version}/
cp %{SOURCE3} .
%patch0
popd

%build
export CLASSPATH=%(build-classpath avalon-logkit junit commons-logging log4j)
export CLASSPATH="$CLASSPATH:../target/%{name}-api-%{version}.jar"
ant jar test javadoc
# Convert to OSGi bundle
java -jar %{_javadir}/aqute-bndlib.jar wrap target/%{name}-api-%{version}.jar

# build implementation now
pushd %{name}-impl-%{version}
# tests removed because we don't have jmock
rm -rf src/test/*
ant jar javadoc
# Convert to OSGi bundle
java -jar %{_javadir}/aqute-bndlib.jar wrap target/%{name}-impl-%{version}.jar
popd

%install
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/
install -d -m 755 $RPM_BUILD_ROOT/%{_mavenpomdir}

install -m 644 target/%{name}-api-%{version}.bar $RPM_BUILD_ROOT%{_javadir}/%{name}-api.jar
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}/%{name}-api

# pom file
install -pm 644 %{name}-api-%{version}.pom $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP-%{name}-api.pom
%add_to_maven_depmap %{name} %{name}-api %{version} JPP %{name}-api
%add_to_maven_depmap org.apache.avalon.framework %{name}-api %{version} JPP %{name}-api

# javadocs
cp -pr dist/docs/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}/%{name}-api/


pushd %{name}-impl-%{version}
install -m 644 target/%{name}-impl-%{version}.bar $RPM_BUILD_ROOT%{_javadir}/%{name}-impl.jar
ln -sf %{_javadir}/%{name}-impl.jar ${RPM_BUILD_ROOT}%{_javadir}/%{name}.jar

# pom file
install -pm 644 %{name}-impl-%{version}.pom $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP-%{name}-impl.pom
%add_to_maven_depmap %{name} %{name}-impl %{version} JPP %{name}-impl
%add_to_maven_depmap org.apache.avalon.framework %{name}-impl %{version} JPP %{name}-impl
%add_to_maven_depmap %{name} %{name} %{version} JPP %{name}-impl

# javadocs
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}/%{name}-impl
cp -pr dist/docs/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}/%{name}-impl/
popd

%post
%update_maven_depmap

%postun
%update_maven_depmap


%files
%defattr(-,root,root,-)
%doc LICENSE.txt NOTICE.txt
%{_mavenpomdir}/JPP-%{name}-api.pom
%{_mavenpomdir}/JPP-%{name}-impl.pom
%{_javadir}/%{name}-api.jar
%{_javadir}/%{name}-impl.jar
%{_javadir}/%{name}.jar
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(-,root,root,-)
%doc LICENSE.txt NOTICE.txt
%{_javadocdir}/%{name}



%changelog
* Sun Nov 27 2011 Guilherme Moro <guilherme@mandriva.com> 4.3-5
+ Revision: 733850
- rebuild
- imported package avalon-framework

* Tue Mar 15 2011 Stéphane Téletchéa <steletch@mandriva.org> 0:4.3-1
+ Revision: 645024
- update to new version 4.3

* Tue Nov 30 2010 Oden Eriksson <oeriksson@mandriva.com> 0:4.2.0-1.4.3mdv2011.0
+ Revision: 603485
- rebuild

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 0:4.2.0-1.4.2mdv2010.1
+ Revision: 522113
- rebuilt for 2010.1

* Sun Aug 09 2009 Oden Eriksson <oeriksson@mandriva.com> 0:4.2.0-1.4.1mdv2010.0
+ Revision: 413151
- rebuild

* Fri Jan 04 2008 David Walluck <walluck@mandriva.org> 0:4.2.0-1.4.0mdv2008.1
+ Revision: 145502
- fix build

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)
    - remove unnecessary Requires(post) on java-gcj-compat


* Wed Dec 13 2006 David Walluck <walluck@mandriva.org> 4.2.0-1.2mdv2007.0
+ Revision: 96200
- update Source URL
- update

* Tue Dec 12 2006 David Walluck <walluck@mandriva.org> 0:4.2.0-1.1mdv2007.1
+ Revision: 95176
- Import avalon-framework

* Tue Sep 05 2006 David Walluck <walluck@mandriva.org> 0:4.2.0-1.1mdv2007.0
- add missing (Build)Requires: log4j

* Fri Sep 01 2006 David Walluck <walluck@mandriva.org> 0:4.2.0-1mdv2007.0
- 4.2.0
- empty manual package
- use $ instead of %% for build-classpath
- set OPT_JAR_LIST for tests
- clean %%{buildroot} in %%install

* Mon Jun 12 2006 David Walluck <walluck@mandriva.org> 0:4.1.4-2.3mdv2007.0
- rebuild for libgcj.so.7
- aot compile
- fix build

* Sat May 14 2005 David Walluck <walluck@mandriva.org> 0:4.1.4-2.2mdk
- rebuild as non-bootstrap

* Fri May 13 2005 David Walluck <walluck@mandriva.org> 0:4.1.4-2.1mdk
- release

* Thu Nov 04 2004 Gary Benson <gbenson@redhat.com> 0:4.1.4-2jpp_5fc
- Build into Fedora.

* Fri Oct 29 2004 Gary Benson <gbenson@redhat.com> 0:4.1.4-2jpp_4fc
- Bootstrap into Fedora.

* Fri Oct 01 2004 Andrew Overholt <overholt@redhat.com> 0:4.1.4-2jpp_3rh
- Remove avalan-logkit as a Requires

* Mon Mar 08 2004 Frank Ch. Eigler <fche@redhat.com> 0:4.1.4-2jpp_2rh
- RH vacuuming part II

* Fri Mar 05 2004 Frank Ch. Eigler <fche@redhat.com> 0:4.1.4-2jpp_1rh
- RH vacuuming

